Index: src/interpreter/bytecode-array-builder.h |
diff --git a/src/interpreter/bytecode-array-builder.h b/src/interpreter/bytecode-array-builder.h |
index 833e26b5a2e6896a9c63eecb34207c472fe6ba4f..825a98db2047b5c32b0e66ab4d93776bf791884b 100644 |
--- a/src/interpreter/bytecode-array-builder.h |
+++ b/src/interpreter/bytecode-array-builder.h |
@@ -94,11 +94,15 @@ class BytecodeArrayBuilder final : public ZoneObject { |
int feedback_slot, |
LanguageMode language_mode); |
- // Load the object at |slot_index| in |context| into the accumulator. |
- BytecodeArrayBuilder& LoadContextSlot(Register context, int slot_index); |
- |
- // Stores the object in the accumulator into |slot_index| of |context|. |
- BytecodeArrayBuilder& StoreContextSlot(Register context, int slot_index); |
+ // Load the object at |slot_index| at |depth| in the context chain starting |
+ // with |context| into the accumulator. |
+ BytecodeArrayBuilder& LoadContextSlot(Register context, int slot_index, |
+ int depth); |
+ |
+ // Stores the object in the accumulator into |slot_index| at |depth| in the |
+ // context chain starting with |context|. |
+ BytecodeArrayBuilder& StoreContextSlot(Register context, int slot_index, |
+ int depth); |
// Register-accumulator transfers. |
BytecodeArrayBuilder& LoadAccumulatorWithRegister(Register reg); |